Welcome to autoBOT’s documentation — autoBOTLib documentation

# Welcome to autoBOT’s documentation

autoBOT is an autoML system for automatic explainable classification of texts. It includes automatically generated features at different granularities, evolved to offer optimal performance/explainability tradeoff.

About:

- Key idea underlying autoBOTLib

Tutorial and first steps:

- Installation
- autoBOTLib library
- Suggested use
- Model persistence
- autoBOTLib CLI
- Feature types
- Using custom classifiers
- Using custom feature transformers
  - Using custom features
  - Extending existing feature spaces
- Obtaining underlying representations
- Singularity container for autoBOT
- Using custom background knowledge
- Using custom metrics
- Potentially interesting further work
  - Extensions with contextual neural representations
  - Improving the classification phase
  - Speeding up evolution
  - Meta-transfer learning
- Releases
- autoBOT API
- Scaling up (SLING)
- Performance on shared tasks

Contents:

- autoBOTLib
  - autoBOTLib package
    - Subpackages
      - autoBOTLib.features package
      - autoBOTLib.learning package
      - autoBOTLib.misc package
      - autoBOTLib.optimization package
    - Submodules
    - autoBOTLib.cli module
    - Module contents